Welcome to NCRAR audio's documentation!
=======================================

Installing
----------

This can be installed via pip:

    pip install ncrar-audio


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   Module API documentation <api/modules>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
